package jeux_etudiant;

import java.util.Vector;

/**
 * @author jub <br>
 * Le monde permet la communication entre le jeux et les entits <br>
 * Il est compos d'une dimension, d'une collection d'entits, d'un gestionnaire de sprite et d'un gestionnaire de son. 
 */
public class World {
	/**
	 * La largeur du jeux
	 */
	private int width = 800;
	/**
	 * La hauteur du jeux
	 */
	private int height = 600;
	/**
	 * La collection des entits qui peuplent le monde.
	 */
	private Vector<Entity> entities;
	
	/**
	 * Le gestionnaire de sprite
	 */
	private SpriteCache spriteCache;
	/**
	 * Le gestionnaire de son
	 */
	private SoundCache soundCache;

	/**
	 * @param width la largeur
	 * @param height la hauteur <br>
	 * construit un monde avec une dimension donne.
	 */
	public World(int width, int height) {
		super();
		this.width = width;
		this.height = height;
		entities = new Vector<Entity>();
		spriteCache = new SpriteCache();
		soundCache = new SoundCache();
	}

	/**
	 * Construit un monde en 800 par 600
	 */
	public World()
	{
		this(800,600);
	}
	
	

	/**
	 * @param entity la nouvelle entit<br>
	 * Permet de peupler le monde avec un nouvelle entit
	 */
	public void addEntity(Entity entity)
	{
		entities.add(entity);
	}

	/**
	 * @param entity l'entit qui quitte le monde <br>
	 * Permet de supprimer une entit du monde
	 */
	public void removeEntity(Entity entity)
	{
		entities.remove(entity);
	}

	/**
	 * @return La largueur
	 */
	public int getWidth() {
		return width;
	}

	/**
	 * @param width La largueur  positionner.
	 */
	public void setWidth(int width) {
		this.width = width;
	}

	/**
	 * @return La hauteur
	 */
	public int getHeight() {
		return height;
	}

	/**
	 * @param height La hauteur  positionner.
	 */
	public void setHeight(int height) {
		this.height = height;
	}

	/**
	 * @return Les entits du monde
	 */
	public  Vector<Entity> getEntities() {
		return entities;
	}

	/**
	 * @param entities les entits qui peuleront le monde
	 */
	public void setEntities(Vector<Entity> entities) {
		this.entities = entities;
	}

	/**
	 * @return le gestionnaire de sprite
	 */
	public SpriteCache getSpriteCache() {
		return spriteCache;
	}

	/**
	 * @return le gestionnaire de sons
	 */
	public SoundCache getSoundCache() {
		return soundCache;
	}

	






}
